<template>

  <div class="app-container">

    <el-card class="box-card" >
      <el-row type="flex" align="middle" justify="space-between">
        <el-col :xl="8" :lg="8" :md="10" :sm="8" :xs="6">
        <div class="icon-container" style="background-color: #1890FF">
          <i class="el-icon-wallet"></i>
        </div>
        </el-col>
        <el-col :xl="14" :lg="14" :md="12" :sm="14" :xs="16">
          <div class="dashboard">
            <div class="dashboard-item">
              <h3 style="color: #5C9BF8">{{ count.total }}</h3>
              <p>设备总数</p >
            </div>
              <div class="dashboard-item">
                <h3 style="color: #5C9BF8">{{ count.video }}</h3>
                <p>视频设备数</p >
              </div>
            <div class="dashboard-item">
              <h3 style="color: #5C9BF8">{{ count.car }}</h3>
              <p>车辆设备数</p >
            </div>
            <div class="dashboard-item">
              <h3 style="color: #5C9BF8">{{ count.face }}</h3>
              <p>人脸设备数</p >
            </div>

            <div class="dashboard-item">
              <h3 style="color: #3eba45">{{ count.examine }}</h3>
              <p>考核中</p >
            </div>
            <div class="dashboard-item">
              <h3 style="color: #6f7583">{{ count.notExamine }}</h3>
              <p>未考核</p >
            </div>
          </div>
        </el-col>
      </el-row>
    </el-card>

    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch">
      <el-form-item label="关键字" prop="keyword">
        <el-input
          v-model="queryParams.keyword"
          placeholder="请输入关键字"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="考核状态" prop="examineStatus">
        <el-select
          v-model="queryParams.examineStatus"
          placeholder="请选择状态"
          clearable
        >
          <el-option label="考核中" :value="1"/>
          <el-option label="未考核" :value="0"/>
        </el-select>
      </el-form-item>
<!--      <el-form-item label="设备状态" prop="onState">-->
<!--        <el-select-->
<!--          v-model="queryParams.onState"-->
<!--          placeholder="设备状态"-->
<!--          clearable-->
<!--          style="width: 100px"-->
<!--        >-->
<!--        <el-option-->
<!--          v-for="dict in dict.type.camera_state"-->
<!--          :key="dict.value"-->
<!--          :label="dict.label"-->
<!--          :value="dict.value"-->
<!--        />-->
<!--        </el-select>-->
<!--      </el-form-item>-->

      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="small" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="small" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
<!--      <el-col :span="1.5">-->
<!--        <el-button-->
<!--          type="warning"-->
<!--          plain-->
<!--          icon="el-icon-download"-->
<!--          size="mini"-->
<!--          @click="handleExport"-->
<!--        >导出</el-button>-->
<!--      </el-col>-->
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          @click="clearMonitor"
        >清理一机一档</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList" :columns="columns"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="monitorList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" align="center" />
      <el-table-column label="设备名称" align="center" prop="name" width="280" fixed/>
      <el-table-column label="设备编码" align="center" prop="serialNumber" width="180"/>
<!--      <el-table-column label="标签" align="center" prop="publicSecurity" width="180" v-if="columns[0].visible"/>-->
      <el-table-column label="区域" align="center" prop="cameraCaptureArea" width="180" v-if="columns[1].visible"/>
      <el-table-column label="考核状态" align="center" prop="onState" v-if="columns[2].visible">
        <template slot-scope="scope">
<!--          <dict-tag :options="dict.type.camera_state" :value="scope.row.onState"/>-->
          <div v-if="scope.row.onState ==1">考核中</div>
          <div v-else-if="scope.row.onState ==0" >未考核</div>
        </template>
      </el-table-column>
      <el-table-column label="数据时间" align="center" prop="installedTime" width="180" v-if="columns[3].visible"/>
      <el-table-column label="管理单位" align="center" prop="managementUnit" width="180" v-if="columns[4].visible"/>
<!--      <el-table-column v-for="(column, index) in dynamicColumnList" :key="index" :label="column.labelValue" :prop="column.propName" align="center">-->
<!--        <template slot-scope="scope">-->
<!--          {{ getDynamicValue(scope.row, column.propName) }}-->
<!--        </template>-->
<!--      </el-table-column>-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width"  fixed="right">
          <template slot-scope="scope">
            <el-button
              size="mini"
              type="text"
              icon="el-icon-view"
              @click="handleView(scope.row,scope.index)"
            >详细</el-button>
          </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 设备资产详情 -->
    <el-dialog title="操作日志详细" :visible.sync="open" width="800px" append-to-body>
      <el-form ref="form" :model="form" label-width="150px" size="mini">
        <el-row>
          <el-col :span="12">
            <el-form-item label="设备编码：">{{ form.serialNumber }}</el-form-item>
            <el-form-item label="设备名称：">{{ form.name }} </el-form-item>
            <el-form-item label="地区：">{{ form.cameraCaptureArea }} </el-form-item>
            <el-form-item label="管理单位：">{{ form.managementUnit }} </el-form-item>
            <el-form-item label="考核状态：">
              <div v-if="form.onState == 1">考核中</div>
              <div v-else-if="form.onState == 0">未考核</div>
            </el-form-item>
          </el-col>
<!--          <el-col :span="24">-->
<!--            <el-form-item label="地址：">{{ form.address }}</el-form-item>-->
<!--          </el-col>-->
          <el-col :span="24">
            <el-form-item label="数据时间：">{{ form.installedTime }}</el-form-item>
          </el-col>
<!--          <el-col :span="24">-->
<!--            <el-form-item label="管理单位：">{{ form.managementUnit }}</el-form-item>-->
<!--          </el-col>-->
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="open = false">关 闭</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { videoCount, listMonitor, getMonitor, delMonitor, addMonitor, updateMonitor } from "@/api/platform/monitor";
import { getDynamicColumnList } from '@/api/platform/dynamicColumn'
import { dataCenter,clearMonitor,assetManagementCount } from "@/api/platform/data-center";
export default {
  name: "Monitor",
  dicts: ['sys_normal_disable', 'platform_yes_no','camera_state'],
  data() {
    return {
      dynamicColumnList: [],
      // 列信息
      columns: [
        { key: 0, label: `标签`, visible: true },
        { key: 1, label: `区域`, visible: true },
        { key: 2, label: `设备状态`, visible: true },
        { key: 3, label: `数据时间`, visible: true },
        { key: 4, label: `管理单位`, visible: true },
      ],
      count: {
        totalPosts: 0,
        totalMembers: 0,
        postsPercentage: 0,
        totalViews: 0,
        noStore: 0,
        partStore: 0,
        viewsPercentage: 0
      },
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 设备资产表格数据
      monitorList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        serialNumber: null,
        keyword: '',
        onState: null,
        address: null,
        installedTime: null,
        managementUnit: null,
        defaultOrder: null,
        cameraFunType: 1,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        serialNumber: [
          { required: true, message: "设备编码不能为空", trigger: "blur" }
        ],
        name: [
          { required: true, message: "设备名称不能为空", trigger: "blur" }
        ],
        onState: [
          { required: true, message: "设备状态", trigger: "blur" }
        ],
        address: [
          { required: true, message: "地址不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getCount();
    this.getList();
  },
  methods: {
    //清理一机一档
    clearMonitor() {
      this.$modal.confirm('是否确认清理一机一档?').then(function() {
        return clearMonitor();
      }).then(() => {
        this.getList()
        this.getCount();
        this.$modal.msgSuccess("清理成功");
      }).catch(() => {});
    },
    getDyColumn() {
      // 查询动态列
      let params = {
        tableName: 't_monitor'
      }
      getDynamicColumnList(params).then(res => {
        this.dynamicColumnList = res.data
      })
    },
    getDynamicValue(row, propName) {
      let target = row.dynamicColumnList.filter(item => item.propName === propName)
      return target && target.length > 0 ? target[0].columnValue : ''
    },
    /** 查询设备资产列表 */
    getList() {
      this.loading = true;
      // this.getDyColumn()
      dataCenter('assetManagement', this.queryParams).then(response => {
        this.monitorList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
     /** 查询设备资产统计数 */
     getCount() {
       assetManagementCount().then(response => {
        this.count = response.data;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        serialNumber: null,
        name: null,
        onState: null,
        address: null,
        installedTime: null,
        managementUnit: null,
        defaultOrder: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
      this.getCount();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },

    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加设备资产";
    },
    /** 详细按钮操作 */
    handleView(row) {
      this.open = true;
      this.form = row;
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getMonitor(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改设备资产";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateMonitor(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMonitor(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除设备资产编号为"' + ids + '"的数据项？').then(function() {
        return delMonitor(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/monitor/export', {
        ...this.queryParams
      }, `monitor_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
<style lang="scss" scoped>

.box-card {
  background-color: #F5F9FE;
  width: 100%;
  margin-bottom: 20px;
  height: 120px
}
.icon-container {
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 10px;
  width: 20%;
  height: 80px;
  margin-left: 5%;
}
.el-icon-wallet {
  font-size: 50px;
  color: #FFFFFF;
}

.dashboard {
  display: flex;
  gap: 10%;
  align-items: center;
  margin-left: -50%;
}

.dashboard-item {
  text-align: center;
}
</style>
